@@ -4,6 +4,7 @@
 =head1 NAME
 
 GraphViz::Graph - Object Oriented interface to graphviz.
+
 =cut
 
 package GraphViz::Graph;
@@ -15,11 +16,11 @@ use utf8;
 #_{ Version
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 #_}
 #_{ Synopsis
 =head1 SYNOPSIS
@@ -38,6 +39,9 @@ our $VERSION = '0.02';
     # Create .dot file, run graphviz/dot to
     # create filename-without-suffix.png:
     $graph->create('png');
+
+Note: C<GraphViz::Graph> needs C<dot> somewhere in C<$PATH>.
+
 =cut
 #_}
 #_{ use …
@@ -58,7 +62,8 @@ sub new { #_{
 
     my $graph = GraphViz::Graph->new('FileNameBase');
 
-Start a graph. C<'FileNameBase'> is the base name for the produced dot and png/pdf/svg… etc. output file.
+Start a graph. C<'FileNameBase'> is the base name for the produced dot and png/pdf/svg… etc. output file. (See L</create>).
+
 =cut
 
   my $class          = shift;
@@ -76,8 +81,9 @@ Start a graph. C<'FileNameBase'> is the base name for the produced dot and png/p
 
   croak "Unrecognized opts " . join "/", keys %$opts if keys %$opts;
 
-  $self->{nodes} = [];
-  $self->{edges} = [];
+  $self->{nodes     } = [];
+  $self->{edges     } = [];
+  $self->{same_ranks} = [];
 
   bless $self, $class;
   return $self;
@@ -87,10 +93,19 @@ sub label { #_{
 #_{ POD
 =head2 label
 
-    GraphViz::Graph->label({text => 'Graph Title'}');
-    GraphViz::Graph->label({html => '<font point-size="20">Say <font face="Courier">Hello World</font></font>'}');
+    # Add text label:
+    $graph->label({text => 'Graph Title'}');
 
-Add a label to a graph. Most probably used as a title.
+    # Add html label:
+    $graph->label({html => '<font point-size="20">Say <font face="Courier">Hello World</font></font>'}');
+
+    # Position label:
+    my $graph_lbl = $graph->label(…);
+    $graph_lbl -> loc('t'); # t = top
+
+Add a label to a graph. Note, a graph can only have one label. This label is most probably used as a title.
+
+For positioning the label, see L<GraphViz::Graph::Label/loc>.
 
 =cut
 #_}
@@ -108,15 +123,14 @@ sub node { #_{
     # … later:
     $nd_foo -> label({html=>"<b>Bold</b><i>Italic</i>"});
 
-Add a node to a graph
+Add a node to a graph. The returned object is a L<GraphViz::Graph::Node>.
 
 =cut
  #_}
   my $self = shift;
-  my $opts = shift;
+# my $opts = shift;
 
-
-  my $node = GraphViz::Graph::Node -> new($opts);
+  my $node = GraphViz::Graph::Node -> new();
 
   push @{$self->{nodes}}, $node;
 
@@ -154,6 +168,29 @@ Add an edge to a graph.
 
   return $edge;
 
+} #_}
+sub same_rank { #_{
+#_{ POD
+=head2 same_rank
+
+    $graph->same_rank($node_one, $node_two);
+    $graph->same_rank($node_one, $node_two, $node_three, …);
+
+Put two or more L<nodes|GraphViz::Graph::Node> on the same rank.
+
+=cut
+
+  my $self  = shift;
+  my $nodes = [];
+
+  for my $node (@_) { #_{
+    croak "Graph - same_rank: Argument $node should be a GraphViz::Graph::Node" unless $node->isa('GraphViz::Graph::Node');
+    push @$nodes, $node;
+  } #_}
+
+  push @{$self->{same_ranks}}, $nodes;
+
+#_}
 } #_}
 sub write_dot { #_{
 
@@ -168,6 +205,16 @@ sub write_dot { #_{
   for my $edge (@{$self->{edges}}) {
     print $out $edge -> dot_text();
   }
+  for my $nodes (@{$self->{same_ranks}}) {
+
+    print $out "  {rank=same;";
+
+    for my $node (@$nodes) {
+      print $out " $node->{id}";
+    }
+    print $out "}\n";
+
+  }
 
 # Define the graph label end of your dot file,
 # otherwise subgraphs will inherit those properties.
@@ -181,6 +228,23 @@ sub write_dot { #_{
 } #_}
 sub create { #_{
 
+#_{ POD
+=head2 create
+
+    my $graph = GraphViz::Graph->new('my_file');
+
+    # Do stuff...
+    $graph->node(…);
+  
+    # Finally, create the graphviz output:
+    # The call to create produces (as per constructor)
+    #   - my_file.dot
+    #   - my_file.pdf
+    $ graph->create('pdf');
+
+
+=cut
+#_}
   my $self     = shift;
   my $filetype = shift;
 
@@ -206,7 +270,7 @@ This function is internally used by the constructur (C<new()>) of L<GraphViz::Gr
 
   my $node_or_port = shift;
 
-  if (ref $node_or_port eq 'GraphViz::Graph::Node') {
+  if ($node_or_port->isa('GraphViz::Graph::Node')) {
     return $node_or_port->{id};
   }
   unless (ref $node_or_port) {
@@ -237,7 +301,19 @@ copy of the full license at: L<http://www.perlfoundation.org/artistic_license_2_
 
 The tests need L<Test::Files|http://search.cpan.org/search?query=Test%3A%3AFiles&mode=all>.
 
+Since C<GraphViz::Graph> needs C<dot>, the tests are skipped if 
+
 =cut
 
 #_}
+#_{ Source Code
+
+=head1 Source Code
+
+The source code is on L<github|https://github.com/ReneNyffenegger/perl-GraphViz-Graph>
+
+=cut
+
+#_}
+
 'tq84'
